<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation>バージョン情報</translation>
    </message>
    <message>
        <source>Version %1.%2.%3</source>
        <translation>バージョン %1.%2.%3</translation>
    </message>
    <message>
        <source>Licensed under the GPLv3</source>
        <translation>GPLv3 の下でライセンスされています</translation>
    </message>
</context>
<context>
    <name>ChatBox</name>
    <message>
        <source>Chat</source>
        <translation>チャット</translation>
    </message>
</context>
<context>
    <name>CreateGameDialog</name>
    <message>
        <source>Create game</source>
        <translation>ゲームを作成</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Game name</source>
        <translation>ゲーム名</translation>
    </message>
    <message>
        <source>Game type</source>
        <translation>ゲームタイプ</translation>
    </message>
    <message>
        <source>Game mode</source>
        <translation>ゲームモード</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>プレイヤー</translation>
    </message>
    <message>
        <source>Max. Players</source>
        <translation type="obsolete">最大プレーヤー数</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>制限時間</translation>
    </message>
    <message>
        <source>Initial stake</source>
        <translation>初期投資額</translation>
    </message>
    <message>
        <source>Blinds</source>
        <translation>ブラインド</translation>
    </message>
    <message>
        <source>Starting blinds</source>
        <translation>スターティング　ブラインド</translation>
    </message>
    <message>
        <source>Raise factor</source>
        <translation>レイズファクター</translation>
    </message>
    <message>
        <source>Raise time</source>
        <translation>レイズタイム</translation>
    </message>
    <message>
        <source>Private game</source>
        <translation>プライベートゲーム</translation>
    </message>
    <message>
        <source>Password protected</source>
        <translation>パスワード制御</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="obsolete">パスワード:</translation>
    </message>
    <message>
        <source>Max. players</source>
        <translation>最大プレーヤー数</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
</context>
<context>
    <name>GameListTableModel</name>
    <message>
        <source>Name</source>
        <translation>ゲーム名</translation>
    </message>
    <message>
        <source>Gametype</source>
        <translation>ゲームタイプ</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>プレイヤー</translation>
    </message>
    <message>
        <source>State</source>
        <translation>状況</translation>
    </message>
    <message>
        <source>Password Protected</source>
        <translation type="obsolete">パスワード制御</translation>
    </message>
</context>
<context>
    <name>PClient</name>
    <message>
        <source>Server running version %1.%2.%3. Your client ID is %4.</source>
        <translation>サーバーバージョン %1.%2.%3. あなたのクライアントIDは %4 です。</translation>
    </message>
    <message>
        <source>There is a newer version of HoldingNuts available (at least %1.%2.%3)</source>
        <translation>最新バージョンの HoldingNuts をご利用いただけます。（少なくとも　%1.%2.%3)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>The version of the server isn&apos;t compatible anymore with this client version. Please either use an older client version or request the server admin to update the server version.</source>
        <translation>このバージョンのサーバーは、このクライアントバージョンとの互換性がありません。古いクライアントバージョンを使う、又は、サーバーのバージョンをアップデートするよう、サーバー管理者にリクエストして下さい。</translation>
    </message>
    <message>
        <source>The version of this client isn&apos;t compatible anymore with the server. Please download a recent version.</source>
        <translation>このバージョンのクライアントは、既にサーバーとの互換性がありません。最新のバージョンをダウンロードして下さい。</translation>
    </message>
    <message>
        <source>Game (%1) has been started.</source>
        <translation>ゲーム (%1) が始まりました。</translation>
    </message>
    <message>
        <source>Game (%1) has been ended.</source>
        <translation>ゲーム (%1) は終わりました。</translation>
    </message>
    <message>
        <source>A new hand (#%1) begins.</source>
        <translation>ニューハンド (#%1) が始まった。</translation>
    </message>
    <message>
        <source>Your hole cards: [%1 %2].</source>
        <translation>あなたのホールカード: [%1 %2].</translation>
    </message>
    <message>
        <source>The flop: [%1 %2 %3].</source>
        <translation>フロップ: [%1 %2 %3].</translation>
    </message>
    <message>
        <source>The turn: [%1].</source>
        <translation>ターン: [%1].</translation>
    </message>
    <message>
        <source>The river: [%1].</source>
        <translation>リバー: [%1].</translation>
    </message>
    <message>
        <source>%1 was folded.</source>
        <translation>%1 はフォールドした。</translation>
    </message>
    <message>
        <source>%1 folded.</source>
        <translation>%1 はフォールドした。</translation>
    </message>
    <message>
        <source>%1 was checked.</source>
        <translation>%1 はチェックした。</translation>
    </message>
    <message>
        <source>%1 checked.</source>
        <translation>%1 はチェックした。</translation>
    </message>
    <message>
        <source>%1 called %2.</source>
        <translation>%1 は %2 をコールした。</translation>
    </message>
    <message>
        <source>%1 bet to %2.</source>
        <translation>%1 は %2 をベットした。</translation>
    </message>
    <message>
        <source>%1 raised to %2.</source>
        <translation>%1 は %2 にレイズした。</translation>
    </message>
    <message>
        <source>%1 is allin with %2.</source>
        <translation>%1 は %2 でオールインする。</translation>
    </message>
    <message>
        <source>%1 shows %2.</source>
        <translation>%1 がカードを公開 %2。</translation>
    </message>
    <message>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1、あなたの番です!</translation>
    </message>
    <message>
        <source>%1 wins pot #%2 with %3.</source>
        <translation>%1 は、ポット #%2 を %3 で勝利。</translation>
    </message>
    <message>
        <source>%1 receives %3 odd chips of split pot #%2.</source>
        <translation>%1 、スプリットポット #%2 の半端なチップ %3 を受け取る。</translation>
    </message>
    <message>
        <source>Protocol error. The remote host does not seem to be a HoldingNuts server.</source>
        <translation>プロトコールエラー。　リモートホストは、HoldingNutsサーバーでないと思われます。</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>接続中...</translation>
    </message>
    <message>
        <source>Connection error: %1.</source>
        <translation>接続エラー: %1.</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation>接続しました。</translation>
    </message>
    <message>
        <source>Connection closed.</source>
        <translation>接続を中止しました。</translation>
    </message>
    <message>
        <source>Blinds are now at %1/%2.</source>
        <translation>ブラインドは今 %1/%2。</translation>
    </message>
    <message>
        <source>Player %1 broke.</source>
        <translation>プレイヤー %1 は破産。</translation>
    </message>
    <message>
        <source>%2 (%1) joined foyer.</source>
        <translation>%2 (%1) ロビーに入った。</translation>
    </message>
    <message>
        <source>%2 (%1) left foyer.</source>
        <translation>%2 (%1) ロビーを出た。</translation>
    </message>
</context>
<context>
    <name>PlayerListTableModel</name>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">ゲーム名</translation>
    </message>
    <message>
        <source>Connections</source>
        <translation type="obsolete">接続</translation>
    </message>
</context>
<context>
    <name>Seat</name>
    <message>
        <source>Location: %1</source>
        <translation>ロケーション: %1</translation>
    </message>
    <message>
        <source>Name: %1</source>
        <translation>ネーム: %1</translation>
    </message>
    <message>
        <source>
Location: </source>
        <translation type="obsolete">
ロケーション: </translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>セッティング</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Player info</source>
        <translation>プレーヤー情報</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>ゲーム画面</translation>
    </message>
    <message>
        <source>Log to file</source>
        <translation>ファイルにログする</translation>
    </message>
    <message>
        <source>enabled</source>
        <translation>有効にする</translation>
    </message>
    <message>
        <source>log chat</source>
        <translation>チャットをログ</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Auto-Detect</source>
        <translation>自動判別</translation>
    </message>
    <message>
        <source>Sounds</source>
        <translation>サウンド</translation>
    </message>
    <message>
        <source>only on focus</source>
        <translation>フォーカスした時のみ</translation>
    </message>
    <message>
        <source>UUID</source>
        <translation>UUID</translation>
    </message>
    <message>
        <source>generate</source>
        <translation>発行</translation>
    </message>
    <message>
        <source>clear</source>
        <translation>クリア</translation>
    </message>
    <message>
        <source>Player name</source>
        <translation>プレーヤー名</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>ロケーション</translation>
    </message>
    <message>
        <source>Show strength of hand</source>
        <translation>ハンドの強さを表示する</translation>
    </message>
    <message>
        <source>Centralized table view</source>
        <translation>自分をテーブルの中心にする</translation>
    </message>
    <message>
        <source>Card deck</source>
        <translation>カードデッキ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>クラッシック</translation>
    </message>
    <message>
        <source>Log and chat</source>
        <translation>ログとチャット</translation>
    </message>
    <message>
        <source>Bring window to top</source>
        <translation>画面を一番上にする</translation>
    </message>
    <message>
        <source>Display time in foyer chat</source>
        <translation>ロビーでのチャットの時間を表示</translation>
    </message>
    <message>
        <source>Display join/left messages</source>
        <translation>出入りのメッセージを表示</translation>
    </message>
    <message>
        <source>Display game states</source>
        <translation>ゲーム状況を表示</translation>
    </message>
    <message>
        <source>Display player chat</source>
        <translation>プレーヤーのチャットを表示</translation>
    </message>
    <message>
        <source>Display player actions</source>
        <translation>プレーヤーのアクションを表示</translation>
    </message>
    <message>
        <source>Display hole/community cards</source>
        <translation>ホール／コミュニティカードを表示</translation>
    </message>
    <message>
        <source>Foyer chat verbosity</source>
        <translation>ロビーでのチャットオプション</translation>
    </message>
    <message>
        <source>Table chat verbosity</source>
        <translation>テーブルでのチャットオプション</translation>
    </message>
</context>
<context>
    <name>WMain</name>
    <message>
        <source>HoldingNuts Foyer</source>
        <translation>HoldingNuts ロビー</translation>
    </message>
    <message>
        <source>Game name filter:</source>
        <translation type="obsolete">ゲーム名フィルター:</translation>
    </message>
    <message>
        <source>&amp;Register</source>
        <translation>登録する(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Unregister</source>
        <translation>登録しない(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Open table</source>
        <translation>テーブルを開く(&amp;O)</translation>
    </message>
    <message>
        <source>Game ID</source>
        <translation>ゲームID</translation>
    </message>
    <message>
        <source>Initial stakes</source>
        <translation>初期投資額</translation>
    </message>
    <message>
        <source>Player timeout</source>
        <translation>プレーヤーの制限時間</translation>
    </message>
    <message>
        <source>Blinds</source>
        <translation>ブラインド</translation>
    </message>
    <message>
        <source>The desired server (domain-name or IP) to connect with.
You can optionally specify a port number.
Format: &lt;host&gt;[:&lt;port&gt;]</source>
        <translation>接続ご希望のサーバー（ドメインネーム又はIP）
オプションとしてポート番号を指定することができます。
フォーマット: &lt;host&gt;[:&lt;port&gt;]</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>接続(&amp;C)</translation>
    </message>
    <message>
        <source>Cl&amp;ose</source>
        <translation>切断(&amp;o)</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>サーバー:</translation>
    </message>
    <message>
        <source>Create own game</source>
        <translation>自分のゲームを作る</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>セッティング(&amp;S)</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>&amp;Test</source>
        <translation>テスト(&amp;T)</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了する(&amp;Q)</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;Handbook</source>
        <translation>ハンドブック(&amp;H)</translation>
    </message>
    <message>
        <source>CTRL+H</source>
        <translation>CTRL+H</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <source>CTRL+A</source>
        <translation>CTRL+A</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>ゲーム(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Error connecting.</source>
        <translation>接続エラー。</translation>
    </message>
    <message>
        <source>Private game</source>
        <translation>プライベートゲーム</translation>
    </message>
    <message>
        <source>Please enter the game password:</source>
        <translation>ゲームパスワードを入力して下さい:</translation>
    </message>
    <message>
        <source>You may need to restart the client for all settings to take effect.</source>
        <translation>全てのセッティングを有効にするには、プログラムの再スタートが必要かもしれません。</translation>
    </message>
    <message>
        <source>THNL</source>
        <translation>THNL</translation>
    </message>
    <message>
        <source>unkown gametype</source>
        <translation>不明なゲームタイプ</translation>
    </message>
    <message>
        <source>Cash game</source>
        <translation>キャッシュゲーム</translation>
    </message>
    <message>
        <source>Tournament</source>
        <translation>トーナメント</translation>
    </message>
    <message>
        <source>Sit&apos;n&apos;Go</source>
        <translation>Sit&apos;n&apos;Go</translation>
    </message>
    <message>
        <source>unkown gamemode</source>
        <translation>不明なゲームモード</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation>待機中</translation>
    </message>
    <message>
        <source>Started</source>
        <translation>進行中</translation>
    </message>
    <message>
        <source>Ended</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>unkown gamestate</source>
        <translation>不明なゲーム状態</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>ようこそ</translation>
    </message>
    <message>
        <source>hide started</source>
        <translation>既に始まったゲームを隠す</translation>
    </message>
    <message>
        <source>hide private</source>
        <translation>プライベートゲームを隠す</translation>
    </message>
    <message>
        <source>&amp;Start game</source>
        <translation>ゲームを始める(&amp;S)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Connections</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>The table will be opened on the next hand.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WTable</name>
    <message>
        <source>&amp;Fold</source>
        <translation>フォールド(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>ショウ(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Muck</source>
        <translation>マック(&amp;M)</translation>
    </message>
    <message>
        <source>I&apos;m bac&amp;k</source>
        <translation>ゲームに戻る (&amp;K)</translation>
    </message>
    <message>
        <source>Sit&amp;out</source>
        <translation>休場する(&amp;o)</translation>
    </message>
    <message>
        <source>Min</source>
        <translation>ミニマム</translation>
    </message>
    <message>
        <source>1/4</source>
        <translation>1/4</translation>
    </message>
    <message>
        <source>1/2</source>
        <translation>1/2</translation>
    </message>
    <message>
        <source>3/4</source>
        <translation>3/4</translation>
    </message>
    <message>
        <source>Pot</source>
        <translation>ポット</translation>
    </message>
    <message>
        <source>Max</source>
        <translation type="obsolete">マックス</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>HoldingNuts table</source>
        <translation>HoldingNuts テーブル</translation>
    </message>
    <message>
        <source>&amp;Call %1</source>
        <translation>コール(&amp;C) %1</translation>
    </message>
    <message>
        <source>&amp;Raise %1</source>
        <translation>レイズ(&amp;R) %1</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>チェック(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Bet %1</source>
        <translation>ベット(&amp;B) %1</translation>
    </message>
    <message>
        <source>&amp;Allin %1</source>
        <translation>オールイン(&amp;A) %1</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>フォールド</translation>
    </message>
    <message>
        <source>Allin %1</source>
        <translation>オールイン %1</translation>
    </message>
    <message>
        <source>Call %1</source>
        <translation>コール %1</translation>
    </message>
    <message>
        <source>Check/Fold</source>
        <translation>チェック/フォールド</translation>
    </message>
    <message>
        <source>Check</source>
        <translation>チェック</translation>
    </message>
    <message>
        <source>Main pot: %1</source>
        <translation>メインポット: %1</translation>
    </message>
    <message>
        <source>Side pot %1: %2</source>
        <translation>サイドポット %1: %2</translation>
    </message>
    <message>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1、あなたの番です！</translation>
    </message>
    <message>
        <source>%1, you have %2 seconds left to respond!</source>
        <translation>%1、次のアクションまで残り %2 秒です！</translation>
    </message>
    <message>
        <source>Saved screenshot: %1.</source>
        <translation>保存されたスクリーンショット: %1.</translation>
    </message>
    <message>
        <source>Unable to save screenshot in %1.</source>
        <translation>%1 にスクリーンショットを保存できません。</translation>
    </message>
    <message>
        <source>Spades</source>
        <translation>スペード</translation>
    </message>
    <message>
        <source>Hearts</source>
        <translation>ハート</translation>
    </message>
    <message>
        <source>Diamonds</source>
        <translation>ダイヤ</translation>
    </message>
    <message>
        <source>Clubs</source>
        <translation>クラブ</translation>
    </message>
    <message>
        <source>Deuce</source>
        <translation>デュース</translation>
    </message>
    <message>
        <source>Deuces</source>
        <translation>デュース</translation>
    </message>
    <message>
        <source>Three</source>
        <translation>スリー</translation>
    </message>
    <message>
        <source>Threes</source>
        <translation>スリー</translation>
    </message>
    <message>
        <source>Four</source>
        <translation>フォー</translation>
    </message>
    <message>
        <source>Fours</source>
        <translation>フォー</translation>
    </message>
    <message>
        <source>Five</source>
        <translation>ファイブ</translation>
    </message>
    <message>
        <source>Fives</source>
        <translation>ファイブ</translation>
    </message>
    <message>
        <source>Six</source>
        <translation>シックス</translation>
    </message>
    <message>
        <source>Sixes</source>
        <translation>シックス</translation>
    </message>
    <message>
        <source>Seven</source>
        <translation>セブン</translation>
    </message>
    <message>
        <source>Sevens</source>
        <translation>セブン</translation>
    </message>
    <message>
        <source>Eight</source>
        <translation>エイト</translation>
    </message>
    <message>
        <source>Eights</source>
        <translation>エイト</translation>
    </message>
    <message>
        <source>Nine</source>
        <translation>ナイン</translation>
    </message>
    <message>
        <source>Nines</source>
        <translation>ナイン</translation>
    </message>
    <message>
        <source>Ten</source>
        <translation>テン</translation>
    </message>
    <message>
        <source>Tens</source>
        <translation>テン</translation>
    </message>
    <message>
        <source>Jack</source>
        <translation>ジャック</translation>
    </message>
    <message>
        <source>Jacks</source>
        <translation>ジャック</translation>
    </message>
    <message>
        <source>Queen</source>
        <translation>クイーン</translation>
    </message>
    <message>
        <source>Queens</source>
        <translation>クイーン</translation>
    </message>
    <message>
        <source>King</source>
        <translation>キング</translation>
    </message>
    <message>
        <source>Kings</source>
        <translation>キング</translation>
    </message>
    <message>
        <source>Ace</source>
        <translation>エース</translation>
    </message>
    <message>
        <source>Aces</source>
        <translation>エース</translation>
    </message>
    <message>
        <source>High Card</source>
        <translation>ハイカード</translation>
    </message>
    <message>
        <source>One Pair</source>
        <translation>ワンペア</translation>
    </message>
    <message>
        <source>Two Pair</source>
        <translation>ツーペア</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 と %2</translation>
    </message>
    <message>
        <source>Three Of A Kind</source>
        <translation>スリー　オブ　ア　カインド</translation>
    </message>
    <message>
        <source>Straight</source>
        <translation>ストレート</translation>
    </message>
    <message>
        <source>%1 high</source>
        <translation>%1 ハイ</translation>
    </message>
    <message>
        <source>Flush</source>
        <translation>フラッシュ</translation>
    </message>
    <message>
        <source>Full House</source>
        <translation>フルハウス</translation>
    </message>
    <message>
        <source>Four Of A Kind</source>
        <translation>フォー　オブ　ア　カインド</translation>
    </message>
    <message>
        <source>Royal Flush</source>
        <translation>ロイヤルフラッシュ</translation>
    </message>
    <message>
        <source>Straight Flush</source>
        <translation>ストレートフラッシュ</translation>
    </message>
    <message>
        <source>Allin</source>
        <translation>オールイン</translation>
    </message>
</context>
</TS>
